@@ -415,7 +415,7 @@ class InfEngineServer:
         engine.install(dldata, dlsources, db_name=db_name)
 
         shutil.rmtree(temp_dir_path)
-        self.restart()
+        self.respawn()
 
     def delete_dl(self, database_name):
         """ Delete DL databases. """
