@@ -142,6 +142,7 @@ class InfEngineServerEngine:
 
         cmd += f" {configfile} 2>&1"
 
+        self._logger.debug(f"Compiling Dl data: {cmd}")
         completed_process = subprocess.run(cmd, shell=True)
 
         if completed_process.returncode:
@@ -228,10 +229,10 @@ class InfEngineServerEngine:
                 )
                 shutil.copy(sources_aliases, dldata_path / INF_ENGINE_FILE_ALIASES)
 
-        # Switch softlinks
+        # Switching symlinks
         self._logger.debug(
             f"Creating a symlink from {dldata_path / INF_ENGINE_FILE_DLDATA_VAR}"
-            f" to {self._engine_dir / INF_ENGINE_LINK_DLDATA}"
+            f" to {self._engine_dir / (INF_ENGINE_PATH_DLDATA + INF_ENGINE_FILE_DLDATA_VAR)}"
         )
         symlink(
             dldata_path / INF_ENGINE_FILE_DLDATA_VAR,
