@@ -1,18 +1,15 @@
 import datetime
-import random
-import string
 import subprocess
 import tempfile
 from pathlib import Path
 
 
-def create_dir(parent_dir: Path) -> Path:
+def create_dir(parent_dir: Path, db_name: str) -> Path:
     """ Create a directory. """
 
-    randomized_name = "".join(random.choices(string.ascii_letters, k=6))
     temp_dir = (
         parent_dir / f"{datetime.datetime.now().strftime('%Y-%m-%d_%H-%M-%S')}"
-        f"_{randomized_name}"
+        f"_{db_name}"
     )
     temp_dir.mkdir(parents=True)
 
